/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.crop.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * Model object representing a crop
 * @author Merijn Zengers
 */
public class Crop extends CropBean implements Serializable {
    
    private List<Race> races;
    private List<Genus> genera;
    private String source = "";
    public static final String PROP_GENUS = "genera"; 
    public static final String PROP_RACE = "races";
    public static final String USER_INPUT = "user_input";
    
    public Crop(String source){
        this.source = source;
        races = new ArrayList();
        genera = new ArrayList<>();
    }

    public void setGenera(ArrayList genera) {
        List<Genus> old = this.genera;
        this.genera = genera;
        getPropertyChangeSupport().firePropertyChange(PROP_GENUS, old, genera);
    }

    public void setRaces(ArrayList races) {
        List<Race> old = this.races;
        this.races = races;
        getPropertyChangeSupport().firePropertyChange(PROP_RACE, old, races);
    }
    
    public List<Race> getRaces() {
        return races;
    }

    public String getSource() {
        return source;
    }
    
    public void addRace(Race race){
        List<Race> old = new ArrayList<>(this.races); 
        this.races.add(race);
        getPropertyChangeSupport().firePropertyChange(PROP_RACE, null, race);
        fireUndoableEvent(PROP_RACE, this, old, this.races);
    }
            
    public void removeRace(Race race){
        List<Race> old = new ArrayList<>(this.races); 
        this.races.remove(race);
        getPropertyChangeSupport().firePropertyChange(PROP_RACE, race, null);
        fireUndoableEvent(PROP_RACE, this, old, this.races);
    }
    
    public List<Genus> getGenera() {
        return genera;
    }

    public void addGenus(Genus genus) {
        List<Genus> old = new ArrayList<>(this.genera); 
        this.genera.add(genus);
        getPropertyChangeSupport().firePropertyChange(PROP_GENUS, null, genus);
        fireUndoableEvent(PROP_GENUS, this, old, this.genera);
    }
    
    public void removeGenus(Genus genus){
        List<Genus> old = new ArrayList<>(this.genera); 
        this.genera.remove(genus);
        getPropertyChangeSupport().firePropertyChange(PROP_GENUS, genus, null);
        fireUndoableEvent(PROP_GENUS, this, old, this.genera);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        if(!super.equals(obj)){
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = super.hashCode();
        return hash;
    }
    
    
    
}
