/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.crop.model;

import java.util.List;

/**
 * Interface to indicate that your implementation is able to provide Crops
 * Register your implementation as follows:
 * @ServiceProvider(service=CropProvider.class)
 * 
 * @author Gerben Feenstra & Merijn Zengers
 */
public interface CropProvider {
   
    /**
     * Unique ID
     * @return Unique ID as String
     */
    String getId();
    
    /**
     * Get last update date in ms since epoch
     * @return Datetime in ms
     */
    long getLastUpdated();
    
    /**
     * Retrieve latest list of Crops
     * @return Latest list of crops
     */
    List<Crop> getCrops();
}
