/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.crop.model;

import java.io.IOException;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObject;
import org.openide.loaders.DataObjectNotFoundException;

/**
 * Interface for CropServices
 * Implementation allows to find and create crops
 * To register your Service add @ServiceProvider(service=AgroSenseCropService.class) too your class
 * @author Merijn Zengers
 */
public interface CropService {
    
    /**
     * Gets the cropStorage object which holds all the crops
     * @param project the projects to get the CropStorage object for
     * @return the found CropStorage object
     * @throws DataObjectNotFoundException
     * @throws IOException 
     */
    public CropsStorage getCropsStorage(Project project) throws DataObjectNotFoundException, IOException;
    
    /**
     * Adds the Crop to all the projects registered in the project list
     * To register a project too the project list use addStockProject
     * @param crop the crop to add too the registered projects
     * @throws DataObjectNotFoundException
     * @throws IOException 
     */
    public void addCrop(Crop crop) throws DataObjectNotFoundException, IOException;
    
    /**
     * Add a crop to a particular project
     * @param project the project to add the crop too
     * @param crop the crop to add too the project
     * @throws DataObjectNotFoundException
     * @throws IOException 
     */
    public void addCrop(Project project, Crop crop) throws DataObjectNotFoundException, IOException;
    
    /**
     * Gets the dataObject in which the CropStorage object is wrapped.
     * @param project the project in which the DataObject must be found
     * @return The found DataObject
     * @throws DataObjectNotFoundException
     * @throws IOException 
     */
    public DataObject getCropsStorageDataObject(Project project) throws DataObjectNotFoundException, IOException ;
    
    /**
     * Adds a project too registered stock project list
     * When a project is added to this list the service will add and remove 
     * crops from your project when methods to add and remove crops are called with no project specified  
     * @param project the  project to register
     */
    public void addStockProject(Project project);
    
    /**
     * 
     * @param project 
     */
    public void removeStockProject(Project project);
    
    
    /**
     * Method to get the crop folder containing crops
     *
     * @param projectDir the projectDir the crop directory should reside in
     * @param create if not found create the folder
     * @return the found or created FileObject
     */
    public FileObject getCropFolder(FileObject projectDir, boolean create);
}
